Coverage report

File |  | statements | missing | excluded |  | coverage
--- | --- | --- | --- | --- | --- | ---
src / invariant / __init__.py |  | 8 | 0 | 0 |  | 100.00%
src / invariant / cacheable.py |  | 33 | 1 | 0 |  | 96.97%
src / invariant / executor.py |  | 68 | 6 | 3 |  | 91.18%
src / invariant / expressions.py |  | 171 | 11 | 0 |  | 93.57%
src / invariant / graph.py |  | 76 | 1 | 2 |  | 98.68%
src / invariant / graph_serialization.py |  | 215 | 33 | 0 |  | 84.65%
src / invariant / hashing.py |  | 42 | 0 | 0 |  | 100.00%
src / invariant / node.py |  | 57 | 1 | 0 |  | 98.25%
src / invariant / ops / __init__.py |  | 3 | 0 | 0 |  | 100.00%
src / invariant / ops / poly.py |  | 40 | 4 | 0 |  | 90.00%
src / invariant / ops / stdlib.py |  | 18 | 0 | 0 |  | 100.00%
src / invariant / params.py |  | 7 | 0 | 0 |  | 100.00%
src / invariant / protocol.py |  | 21 | 7 | 0 |  | 66.67%
src / invariant / registry.py |  | 64 | 9 | 0 |  | 85.94%
src / invariant / store / __init__.py |  | 6 | 0 | 0 |  | 100.00%
src / invariant / store / base.py |  | 22 | 3 | 0 |  | 86.36%
src / invariant / store / chain.py |  | 30 | 0 | 0 |  | 100.00%
src / invariant / store / codec.py |  | 155 | 0 | 0 |  | 100.00%
src / invariant / store / disk.py |  | 47 | 2 | 0 |  | 95.74%
src / invariant / store / memory.py |  | 54 | 2 | 0 |  | 96.30%
src / invariant / store / null.py |  | 9 | 0 | 0 |  | 100.00%
src / invariant / types.py |  | 37 | 1 | 3 |  | 97.30%
Total |  | 1183 | 81 | 8 |  | 93.15%

No items found using the specified filter.